
* THIS VERSION: June 27 2023

// NHIBW     Health index
// BMI_B     Body mass index at birth
// INV_BW    Birth weight **
// INV_ANGA  Gestational age **
// F3AV5     Head circumference at birth (cm) **
// F3AV4     Infant length at birth (cm) **

version 15.0

// ********************
// preliminary analysis
// ********************

macro def W_a NHIBW       // health index
macro def W_b BMI_B       // body mass index at birth
macro def W_c INV_BW      // birth weight
macro def W_d INV_ANGA    // gestational age
macro def W_e F3AV5       // head circumference at birth (cm)
macro def W_f F3AV4       // infant length at birth (cm)
 
* NHIBW is a residual from a regression of INV_ANGA on INV_BW (and site dummies),
* then std to have mean 100 and sd 16. See here:

*scatter $W_a $W_c

* BMI_B is computed from weight and length

*scatter $W_b $W_c
*scatter $W_b $W_f

* it follows that the information available is spanned by 4 `raw' variables:
* birth weight
* gestational age
* head circumference
* length

pca INV_ANGA INV_BW F3AV4 F3AV5, comp(2)

* the first factor explains 82.2% of the variance

cap drop f1 f2
predict f1 f2

* average of principal components by birth weight group

table BWG, c(mean f1 mean f2)
cap drop BWgroup 
gen BWgroup = BWG == "H"
reg f1 BWgroup // average difference between groups
local b = _b[BWgroup]
sum f1
di `b'/r(sd) // average difference between groupsin points of std dev

// ************************************
// *** CHOICE #1: RESIDUALIZE VARIABLES
// ************************************
// treatment-specific residuals with respect to:
// macro def X F3AMAGE married highdrop highgrad collgrad BLACK HISPANIC
// to add randomization strata controls, run:

*macro def X i.site i.strata // only randomization strata 
*macro def X $X i.site i.strata // add randomization strata 
*macro def X $X boy firstborn i.site i.strata // add randomization strata 
*macro def X // no controls

foreach v of varlist $Y INV_ANGA INV_BW F3AV4 F3AV5 {

	qui regress `v' $X if $D == 1
	qui predict `v'_res if e(sample), residuals
	qui replace `v' = `v'_res if e(sample)  // replace variable with residuals
	qui drop `v'_res
	
	qui regress `v' $X if $D == 0
	qui predict `v'_res if e(sample), residuals
	qui replace `v' = `v'_res if e(sample)
	qui drop `v'_res
}

// ****************************
// *** CHOICE #2: STD VARIABLES
// ****************************

foreach v of varlist $Y INV_ANGA INV_BW F3AV4 F3AV5 {

	egen `v'_std = std(`v')
	*gen `v'_std = `v'
	
}

// *******************************************
// *** OUTCOME #1: MEASUREMENT ERROR VARIANCES
// *******************************************

macro def W1 INV_BW_std   // Birth weight
macro def W2 INV_ANGA_std // Gestational age
macro def W3 F3AV4_std    // Length
macro def W4 F3AV5_std    // Head circumference

cap drop W1sq
gen W1sq = $W1^2

cap drop W2sq
gen W2sq = $W2^2

cap drop W3sq
gen W3sq = $W3^2

cap drop W4sq
gen W4sq = $W4^2

cap drop W1W2
gen W1W2 = $W1*$W2

cap drop W1W3
gen W1W3 = $W1*$W3

cap drop W1W4
gen W1W4 = $W1*$W4

cap drop W2W3
gen W2W3 = $W2*$W3

cap drop W2W4
gen W2W4 = $W2*$W4

cap drop W3W4
gen W3W4 = $W3*$W4

// constrained estimation

/*
#delimit ;
nlsur ($W1  = {muH}) 
      ($W2  = {a2}*{muH})
	  ($W3  = {a3}*{muH})
	  ($W4  = {a4}*{muH})
	  (W1sq = exp({sig2H})+exp({sig21}))
	  (W2sq = {a2}^2*exp({sig2H})+exp({sig22}))
	  (W3sq = {a3}^2*exp({sig2H})+exp({sig23}))
	  (W4sq = {a4}^2*exp({sig2H})+exp({sig24}))
	  (W1W2 = {a2}*exp({sig2H}))
	  (W1W3 = {a3}*exp({sig2H}))
	  (W1W4 = {a4}*exp({sig2H}))
	  (W2W3 = {a2}*{a3}*exp({sig2H}))
	  (W2W4 = {a2}*{a4}*exp({sig2H}))
	  (W3W4 = {a3}*{a4}*exp({sig2H})), vce(robust) ifgnls;
#delimit cr
*/

#delimit ;
nlsur (W1W2 = {a2}*exp({sig2H}))
	  (W1W3 = {a3}*exp({sig2H}))
	  (W1W4 = {a4}*exp({sig2H}))
	  (W2W3 = {a2}*{a3}*exp({sig2H}))
	  (W2W4 = {a2}*{a4}*exp({sig2H}))
	  (W3W4 = {a3}*{a4}*exp({sig2H})), vce(robust) ifgnls;
#delimit cr

local loglH0 = e(ll)
local dfH0 = e(k)

#delimit ;
nlcom (v1: 1-exp(_b[sig2H:_cons])) // Birth weight error variance
      (v2: 1-_b[a2:_cons]^2*exp(_b[sig2H:_cons])) // Gestational age error variance
	  (v3: 1-_b[a3:_cons]^2*exp(_b[sig2H:_cons])) // Length error variance
	  (v4: 1-_b[a4:_cons]^2*exp(_b[sig2H:_cons])) // Head circumference error variance
	  (fv: exp(_b[sig2H:_cons])), post; // Factor variance
#delimit cr

// unconstrained estimation

#delimit ;
nlsur (W1W2 = {muW1W2})
	  (W1W3 = {muW1W3})
	  (W1W4 = {muW1W4})
	  (W2W3 = {muW2W3})
	  (W2W4 = {muW2W4})
	  (W3W4 = {muW3W4}), vce(robust) ifgnls;
#delimit cr

local loglH1 = e(ll)
local dfH1 = e(k)

di "Chi-sq stat over-id: " 2*(`loglH1'-`loglH0')
di "degrees of freedom: " `dfH1'-`dfH0'
di "P-value over-id: " chi2tail(`dfH1'-`dfH0',2*(`loglH1'-`loglH0'))

// *****************************************************
// *** OUTCOME #2: W1 AND INSTRUMENTS FOR APPENDIX TABLE
// *****************************************************

/*
NHIBW       health index
BMI_B       body mass index at birth
INV_BW      birth weight
INV_ANGA    gestational age
F3AV5       head circumference at birth (cm)
F3AV4       infant length at birth (cm)
*/

macro def W2 INV_ANGA_std  
macro def W4 F3AV4_std
macro def W1 INV_BW_std
macro def W3 F3AV5_std // W1 must be changed manually to obtain Table 3

local filewrite="replace"

foreach v of varlist $Y {
	
	// create Ydot here
	
	ivregress 2sls `v'_std ($W1 = $W2 $W3 $W4) $X if $D == 1
	qui estat overid
	qui local sar = round(r(p_score),0.001)
	outreg2 using "${foldlog}\loadings.xls", keep($W1) `filewrite' addtext(W1, $W1, Group, T, Sargan, `sar')
	local filewrite="append"
	qui gen `v'_std_dot1 = `v'_std - _b[$W1]*$W1  if $D == 1 
	qui local lambda1_`v'_std = _b[$W1]
	qui sum $W1                                   if $D == 1
	qui local v1_`v'_std = r(sd)^2
	
	ivregress 2sls `v'_std ($W1 = $W2 $W3 $W4) $X if $D == 0
	qui estat overid
	qui local sar = round(r(p_score),0.001)
	outreg2 using "${foldlog}\loadings.xls", keep($W1) `filewrite' addtext(W1, $W1, Group, C, Sargan, `sar')
	qui gen `v'_std_dot0 = `v'_std - _b[$W1]*$W1  if $D == 0 
	qui local lambda0_`v'_std = _b[$W1]
	qui sum $W1                                   if $D == 0
	qui local v0_`v'_std = r(sd)^2

	// prep variables for regressions below
	
	qui cap gen `v'_std_dot = cond($D == 1,`v'_std_dot1,`v'_std_dot0)
}

// estimate \kappa's
// instead of estimating separate equations with Ydot for treatment and control, I consider one fully interacted specification
// 1-Cognitive development: F57_1_
// 2-Health status: THCS_CUM
// 3-Health status: GHRI_36

// define constraints

tempvar oneminusD 
gen `oneminusD' = 1-$D

// these are within-outcome constraints for T and C groups

constraint 1 [F57_1__std_dot]c.$W1#c.$D/`lambda1_F57_1__std'*`v1_F57_1__std'       =   [F57_1__std_dot]c.$W1#c.`oneminusD'/`lambda0_F57_1__std'*`v0_F57_1__std'
constraint 2 [THCS_CUM_std_dot]c.$W1#c.$D/`lambda1_THCS_CUM_std'*`v1_THCS_CUM_std' = [THCS_CUM_std_dot]c.$W1#c.`oneminusD'/`lambda0_THCS_CUM_std'*`v0_THCS_CUM_std'
constraint 3 [GHRI_36_std_dot]c.$W1#c.$D/`lambda1_GHRI_36_std'*`v1_GHRI_36_std'    =  [GHRI_36_std_dot]c.$W1#c.`oneminusD'/`lambda0_GHRI_36_std'*`v0_GHRI_36_std'

// these are across-outcome constraints

constraint 4 [F57_1__std_dot]c.$W1#c.$D/`lambda1_F57_1__std'*`v1_F57_1__std' = [THCS_CUM_std_dot]c.$W1#c.$D/`lambda1_THCS_CUM_std'*`v1_THCS_CUM_std'
constraint 5 [F57_1__std_dot]c.$W1#c.$D/`lambda1_F57_1__std'*`v1_F57_1__std' = [GHRI_36_std_dot]c.$W1#c.$D/`lambda1_GHRI_36_std'*`v1_GHRI_36_std'

#delimit ;
sureg (F57_1__std_dot   $D c.$W1#c.`oneminusD' c.$W1#c.$D $X)/*
      (ACTPS_36_std_dot $D c.$W1#c.`oneminusD' c.$W1#c.$D $X)*/
	  (THCS_CUM_std_dot $D c.$W1#c.`oneminusD' c.$W1#c.$D $X)/*
	  (SHCI_CUM_std_dot $D c.$W1#c.`oneminusD' c.$W1#c.$D $X)
	  (STETO_36_std_dot $D c.$W1#c.`oneminusD' c.$W1#c.$D $X)
	  (F63V7A_std_dot   $D c.$W1#c.`oneminusD' c.$W1#c.$D $X)
      (BMI_36_std_dot   $D c.$W1#c.`oneminusD' c.$W1#c.$D $X)*/
	  (GHRI_36_std_dot  $D c.$W1#c.`oneminusD' c.$W1#c.$D $X),
	  constr(1 2 3 4 5);
#delimit cr

qui local si2 = -_b[F57_1__std_dot:c.$W1#c.$D]/`lambda1_F57_1__std'*`v1_F57_1__std'
qui sum $W1
qui local nsr = `si2'/r(sd)^2

di `si2' // measurement error variance
di `nsr' // noise to signal ratio = measurement error variance bacause $W1 is standardized



 
