
* THIS VERSION: Sep 2023
* FIRST VERSION: June 27 2021

// ***************************************************
// PROC TO ESTIMATE QTE
// this was modified to estimate unconditional effects
// ***************************************************

cap program drop QTE
program define QTE, rclass

	//  INPUTS: only the outcome $Y

	syntax varlist [, _q(real 0.50)]

	// local variables defined in the procedure
	
	tokenize `varlist'
	
	local y `1'   // outcome
	
	// unconditional QTEs: https://www.stata-journal.com/article.html?article=st0203
	// continuous controls: INV_BW F3AV4 BMI_B INV_ANGA NHIBW F3AV5 + F3AMAGE
	// binary controls: boy firstborn + married highdrop highgrad collgrad BLACK HISPANIC + strata
	// unordered controls: site
	
	// NOTE the definition of X: F3AMAGE married highdrop highgrad collgrad BLACK HISPANIC
	
	#delimit ;
	qui ivqte `y' ($D) if `y' != ., q(`_q')
	                    linear variance mata_opt kernel(gaussian)
						continuous(F3AMAGE) 
	                    dummy(married highdrop highgrad collgrad BLACK HISPANIC strata); 
	qui return scalar  b_all = _b[Quantile_1];
	qui return scalar se_all = _se[Quantile_1];
	#delimit cr				
	
	#delimit ;
	qui ivqte `y' ($D) if `y' != . & strata == 0, q(`_q')
	                                   linear variance mata_opt kernel(gaussian)
									   continuous(F3AMAGE)
									   dummy(married highdrop highgrad collgrad BLACK HISPANIC); 
	qui return scalar  b_lbw = _b[Quantile_1];
	qui return scalar se_lbw = _se[Quantile_1];
	#delimit cr				

	#delimit ;
	qui ivqte `y' ($D) if `y' != . & strata == 1, q(`_q')
	                                   linear variance mata_opt kernel(gaussian)
									   continuous(F3AMAGE)
									   dummy(married highdrop highgrad collgrad BLACK HISPANIC); 
	qui return scalar  b_hbw = _b[Quantile_1];
	qui return scalar se_hbw = _se[Quantile_1];
	#delimit cr				
end	

// ******************************************
// PROC TO ESTIMATE LLR SLOPES AND INTERCEPTS
// ******************************************

cap program drop LRsmoother
program define LRsmoother, rclass

	//  INPUTS: only the outcome $Y

	syntax varlist

	// local variables defined in the procedure
	
	tokenize `varlist'
	
	local y `1'   // outcome

	// estimate QTE

	local i = 0
	
	foreach tau of numlist 0.10(0.01)0.90 {

		local i = `i' + 1
		
		cap qui gen tau = .
		qui replace tau = `tau' in `i'
		
		QTE `y', _q(`tau')
		
		cap qui gen QTE_all = .
		cap qui gen seQTE_all = .
		qui replace QTE_all = r(b_all) in `i'
		qui replace seQTE_all = r(se_all) in `i'

		cap qui gen QTE_lbw = .
		cap qui gen seQTE_lbw = .
		qui replace QTE_lbw = r(b_lbw) in `i'
		qui replace seQTE_lbw = r(se_lbw) in `i'
		
		cap qui gen QTE_hbw = .
		cap qui gen seQTE_hbw = .
		qui replace QTE_hbw = r(b_hbw) in `i'
		qui replace seQTE_hbw = r(se_hbw) in `i'
	}	

	// estimate LLR
	// net install nprobust, from(https://sites.google.com/site/nppackages/nprobust/stata) replace
	
	preserve
	
	keep if tau != .
	
	foreach x in _all _lbw _hbw {
		
		cap drop lprobust*
		qui lprobust QTE`x' tau, eval(tau) kernel(triangular) p(1) deriv(0) genvars
				
		cap drop s1QTE`x' s2QTE`x'
		rename lprobust_gx_us s1QTE`x'
		rename lprobust_gx_bc s2QTE`x'
		drop lprobust*
		
		qui lprobust QTE`x' tau, eval(tau) kernel(triangular) p(1) deriv(1) genvars
		
		cap drop s1dQTE`x' s2dQTE`x'
		rename lprobust_gx_us s1dQTE`x'
		rename lprobust_gx_bc s2dQTE`x'
		drop lprobust*	
	}

	keep tau QTE* s*QTE*
	compress
	save "${foldlog}\QTE_.dta", replace
	
	restore
	
	qui drop tau
	qui drop QTE_all
	qui drop QTE_lbw
	qui drop QTE_hbw

end

// *********
// BOOTSTRAP
// *********

foreach v of varlist F57_1_ THCS_CUM GHRI_36 {
	
	cap drop `v'_std
	*egen `v'_std = std(`v') // activate to std variables
	gen `v'_std = `v' // Note that variables are NOT std
	
	LRsmoother `v'_std
	
	preserve
	
	use "${foldlog}\QTE_.dta", clear

	gen data = 0
	order data tau
	compress
	save "${foldlog}\QTE_`v'.dta", replace
	
	restore
	
	forvalues i=1(1)100 {

		noi di "iteration # " `i'
	
		preserve

		bsample, strata(treat)

		cap drop `v'_std
		*egen `v'_std = std(`v')
		gen `v'_std = `v'

		LRsmoother `v'_std

		use "${foldlog}\QTE_.dta", clear
	
		gen data = `i'
		
		append using "${foldlog}\QTE_`v'.dta"
		order data tau
		compress
		save "${foldlog}\QTE_`v'.dta", replace
		
		restore
	}
	
	erase "${foldlog}\QTE_.dta"
}


// ***************
// AVERAGE EFFECTS
// ***************

foreach v of varlist $Y {

	cap drop `v'_std
	*egen `v'_std = std(`v') // activate to std variables
	gen `v'_std = `v' // Note that variables are NOT std
	
	regress `v'_std $D $X, level(90)
	local k_all_`v' = _b[$D]
	mat def tmp = r(table)
	local k_all_ll_`v' = tmp[5,1]
	local k_all_ul_`v' = tmp[6,1]
	mat drop tmp
	
	regress `v'_std $D $X if strata == 0, level(90)
	local k_lbw_`v' = _b[$D]	
	mat def tmp = r(table)
	local k_lbw_ll_`v' = tmp[5,1]
	local k_lbw_ul_`v' = tmp[6,1]
	mat drop tmp
	
	regress `v'_std $D $X if strata == 1, level(90)
	local k_hbw_`v' = _b[$D]
	mat def tmp = r(table)
	local k_hbw_ll_`v' = tmp[5,1]
	local k_hbw_ul_`v' = tmp[6,1]
	mat drop tmp

}

// **********
// QTE GRAPHS
// **********

local   title_F57_1_ = "Cognitive Development Index"
local title_THCS_CUM = "Morbidity Index"
local  title_GHRI_36 = "General Health Ratings Index"

preserve

foreach v in $Y /*F57_1_ THCS_CUM GHRI_36*/ {

	use "${foldlog}\QTE_`v'.dta", clear

	foreach x in _all _lbw _hbw {

		// intervals using a robust measure of scale

		bysort tau: egen sd_s1QTE`x' = sd(cond(data != 0, s1QTE`x', .))
		bysort tau: egen tmp_s1QTE`x' = median(cond(data != 0, s1QTE`x', .))
		bysort tau: egen mad_s1QTE`x' = median(cond(data != 0, abs(s1QTE`x'-tmp_s1QTE`x'), .))
		bysort tau: replace sd_s1QTE`x' = 1.4826*mad_s1QTE`x' 
		drop tmp_s1QTE`x' mad_s1QTE`x'
		bysort tau: gen sup_s1QTE`x' = s1QTE`x' + 1.96*sd_s1QTE`x' 
		bysort tau: gen inf_s1QTE`x' = s1QTE`x' - 1.96*sd_s1QTE`x' 
	
		bysort tau: egen sd_s2QTE`x' = sd(cond(data != 0, s2QTE`x', .))
		bysort tau: egen tmp_s2QTE`x' = median(cond(data != 0, s2QTE`x', .))
		bysort tau: egen mad_s2QTE`x' = median(cond(data != 0, abs(s2QTE`x'-tmp_s2QTE`x'), .))
		bysort tau: replace sd_s2QTE`x' = 1.4826*mad_s2QTE`x' 
		drop tmp_s2QTE`x' mad_s2QTE`x'
		bysort tau: gen sup_s2QTE`x' = s2QTE`x' + 1.96*sd_s2QTE`x' 
		bysort tau: gen inf_s2QTE`x' = s2QTE`x' - 1.96*sd_s2QTE`x' 

		bysort tau: egen sd_s1dQTE`x' = sd(cond(data != 0, s1dQTE`x', .))
		bysort tau: egen tmp_s1dQTE`x' = median(cond(data != 0, s1dQTE`x', .))
		bysort tau: egen mad_s1dQTE`x' = median(cond(data != 0, abs(s1dQTE`x'-tmp_s1dQTE`x'), .))
		bysort tau: replace sd_s1dQTE`x' = 1.4826*mad_s1dQTE`x' 
		drop tmp_s1dQTE`x' mad_s1dQTE`x'
		bysort tau: gen sup_s1dQTE`x' = s1dQTE`x' + 1.96*sd_s1dQTE`x' 
		bysort tau: gen inf_s1dQTE`x' = s1dQTE`x' - 1.96*sd_s1dQTE`x' 

		bysort tau: egen sd_s2dQTE`x' = sd(cond(data != 0, s2dQTE`x', .))
		bysort tau: egen tmp_s2dQTE`x' = median(cond(data != 0, s2dQTE`x', .))
		bysort tau: egen mad_s2dQTE`x' = median(cond(data != 0, abs(s2dQTE`x'-tmp_s2dQTE`x'), .))
		bysort tau: replace sd_s2dQTE`x' = 1.4826*mad_s2dQTE`x' 
		drop tmp_s2dQTE`x' mad_s2dQTE`x'
		bysort tau: gen sup_s2dQTE`x' = s2dQTE`x' + 1.96*sd_s2dQTE`x' 
		bysort tau: gen inf_s2dQTE`x' = s2dQTE`x' - 1.96*sd_s2dQTE`x' 
		
		// graphs
		
		#delimit ;
		twoway (scatter QTE`x' tau if data == 0, mcolor(black) msize(vtiny))
			   (line s1QTE`x' tau if data == 0, sort lcolor(black))
			   (rarea sup_s1QTE`x' inf_s1QTE`x' tau if data == 0, fcolor(red%5) lcolor(red%5) lwidth(none))
			   if inrange(tau,0.15,0.85), 
			   xtitle("quantile") xscale(range(0 1)) xlabel(0.10(0.05)0.90, labsize(tiny))
			   ytitle("") 
			   subtitle("`title_`v''")
			   yline(`k`x'_`v'', lcolor(green))
		       text(`k`x'_`v'' 0.02 "average", place(s) size(tiny) color(black))
			   scheme(s1color)
			   legend(off) saving(one`x'_`v', replace);
		graph export "${foldgr}\one`x'_`v'.png", replace;
		#delimit cr
		
		#delimit ;
		twoway (line s1dQTE`x' tau if data == 0, lcolor(black))
			   (rarea sup_s1dQTE`x' inf_s1dQTE`x' tau if data == 0, fcolor(red%5) lcolor(red%5) lwidth(none))
			   if inrange(tau,0.15,0.85), 
			   xtitle("quantile") xscale(range(0 1)) xlabel(0.10(0.05)0.90, labsize(tiny))
			   ytitle("")
			   subtitle("`title_`v''")
			   scheme(s1color)
			   legend(off) saving(two`x'_`v', replace);
		graph export "${foldgr}\two`x'_`v'.png", replace;	   
		#delimit cr

		*graph combine one`x'_`v'.gph two`x'_`v'.gph
		
		*graph export "${foldgr}\QTE_`v'`x'.png", replace
		
	}	
	
	#delimit ;
	export excel tau QTE_all s1QTE_all sup_s1QTE_all inf_s1QTE_all s1dQTE_all sup_s1dQTE_all inf_s1dQTE_all 
		   using "${foldgr}\QTEgraphs-data.xlsx" if data == 0, sheet("`v'") sheetreplace firstrow(variables);
	#delimit cr
}

// keep data for graphs in R
//br tau QTE_all s1QTE_all sup_s1QTE_all inf_s1QTE_all s1dQTE_all sup_s1dQTE_all inf_s1dQTE_all if data == 0

foreach x in _all _lbw _hbw {

	graph combine one`x'_F57_1_.gph one`x'_THCS_CUM.gph one`x'_GHRI_36.gph, row(1) scheme(s1color)
		
	graph export "${foldgr}\QTE`x'_pooled.png", replace
			
	erase "one`x'_F57_1_.gph"
	erase "one`x'_THCS_CUM.gph"
	erase "one`x'_GHRI_36.gph"

	graph combine two`x'_F57_1_.gph two`x'_THCS_CUM.gph two`x'_GHRI_36.gph, row(1) scheme(s1color)
		
	graph export "${foldgr}\dQTE`x'_pooled.png", replace
			
	erase "two`x'_F57_1_.gph"
	erase "two`x'_THCS_CUM.gph"
	erase "two`x'_GHRI_36.gph"
}


restore

STOP

// ***************************
// FRANDSEN AND LEFGREN (2018)
// ***************************

set seed 27062007

// compute ranks

foreach v of varlist $Y {

	cap drop rank_`v'
		
	bysort $D: egen rank_`v' = rank(`v'), track //, unique
	bysort $D: gen N = _N if `v' ! = .
	replace rank_`v' = rank_`v' / N
	drop N
}

// std anthropometrics 

foreach w of varlist INV_ANGA INV_BW F3AV4 F3AV5 {

	cap drop `w'_std
	egen `w'_std = std(`w')
}

// specification

#delimit ;
macro def spec1 $D 
                INV_ANGA_std INV_BW_std F3AV4_std F3AV5_std 
                c.INV_ANGA_std#c.$D 
				c.INV_BW_std#c.$D 
				c.F3AV4_std#c.$D 
				c.F3AV5_std#c.$D;
#delimit cr

// pooled regressions without controls

#delimit ;
sureg (rank_F57_1_   $spec1)
      (rank_THCS_CUM $spec1)
	  (rank_GHRI_36  $spec1);
#delimit cr

#delimit ;
test [rank_F57_1_]c.INV_BW_std#c.$D [rank_THCS_CUM]c.INV_BW_std#c.$D [rank_GHRI_36]c.INV_BW_std#c.$D
     [rank_F57_1_]c.F3AV4_std#c.$D [rank_THCS_CUM]c.F3AV4_std#c.$D [rank_GHRI_36]c.F3AV4_std#c.$D
	 [rank_F57_1_]c.INV_ANGA_std#c.$D [rank_THCS_CUM]c.INV_ANGA_std#c.$D [rank_GHRI_36]c.INV_ANGA_std#c.$D
     [rank_F57_1_]c.F3AV5_std#c.$D [rank_THCS_CUM]c.F3AV5_std#c.$D [rank_GHRI_36]c.F3AV5_std#c.$D;
#delimit cr

local p_all = round(r(p),0.001)

#delimit ;
test [rank_F57_1_]c.INV_BW_std#c.$D
     [rank_F57_1_]c.F3AV4_std#c.$D
	 [rank_F57_1_]c.INV_ANGA_std#c.$D
     [rank_F57_1_]c.F3AV5_std#c.$D;
#delimit cr

local p_F57_1_ = round(r(p),0.001)

#delimit ;
test [rank_THCS_CUM]c.INV_BW_std#c.$D
     [rank_THCS_CUM]c.F3AV4_std#c.$D
	 [rank_THCS_CUM]c.INV_ANGA_std#c.$D
     [rank_THCS_CUM]c.F3AV5_std#c.$D;
#delimit cr

local p_THCS_CUM = round(r(p),0.001)

#delimit ;
test [rank_GHRI_36]c.INV_BW_std#c.$D
     [rank_GHRI_36]c.F3AV4_std#c.$D
	 [rank_GHRI_36]c.INV_ANGA_std#c.$D
     [rank_GHRI_36]c.F3AV5_std#c.$D;
#delimit cr

local p_GHRI_36 = round(r(p),0.001)

#delimit ;
outreg2 using "${foldlog}\rank-invariance.xls", replace $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) 
        addtext(P-value all, `p_all', P-value F57_1_, `p_F57_1_', P-value p_THCS_CUM, `p_THCS_CUM', P-value GHRI_36, `p_GHRI_36');
#delimit cr

// pooled regressions with controls

#delimit ;
sureg (rank_F57_1_   $spec1 $X)
      (rank_THCS_CUM $spec1 $X)
	  (rank_GHRI_36  $spec1 $X);
#delimit cr

#delimit ;
test [rank_F57_1_]c.INV_BW_std#c.$D [rank_THCS_CUM]c.INV_BW_std#c.$D [rank_GHRI_36]c.INV_BW_std#c.$D
     [rank_F57_1_]c.F3AV4_std#c.$D [rank_THCS_CUM]c.F3AV4_std#c.$D [rank_GHRI_36]c.F3AV4_std#c.$D
	 [rank_F57_1_]c.INV_ANGA_std#c.$D [rank_THCS_CUM]c.INV_ANGA_std#c.$D [rank_GHRI_36]c.INV_ANGA_std#c.$D
     [rank_F57_1_]c.F3AV5_std#c.$D [rank_THCS_CUM]c.F3AV5_std#c.$D [rank_GHRI_36]c.F3AV5_std#c.$D;
#delimit cr

local p_all = round(r(p),0.001)

#delimit ;
test [rank_F57_1_]c.INV_BW_std#c.$D
     [rank_F57_1_]c.F3AV4_std#c.$D
	 [rank_F57_1_]c.INV_ANGA_std#c.$D
     [rank_F57_1_]c.F3AV5_std#c.$D;
#delimit cr

local p_F57_1_ = round(r(p),0.001)

#delimit ;
test [rank_THCS_CUM]c.INV_BW_std#c.$D
     [rank_THCS_CUM]c.F3AV4_std#c.$D
	 [rank_THCS_CUM]c.INV_ANGA_std#c.$D
     [rank_THCS_CUM]c.F3AV5_std#c.$D;
#delimit cr

local p_THCS_CUM = round(r(p),0.001)

#delimit ;
test [rank_GHRI_36]c.INV_BW_std#c.$D
     [rank_GHRI_36]c.F3AV4_std#c.$D
	 [rank_GHRI_36]c.INV_ANGA_std#c.$D
     [rank_GHRI_36]c.F3AV5_std#c.$D;
#delimit cr

local p_GHRI_36 = round(r(p),0.001)

#delimit ;
outreg2 using "${foldlog}\rank-invariance.xls", append $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) 
        addtext(P-value all, `p_all', P-value F57_1_, `p_F57_1_', P-value p_THCS_CUM, `p_THCS_CUM', P-value GHRI_36, `p_GHRI_36');
#delimit cr



