
* THIS VERSION: July 19 2023

clear all

// ************************************
// LOAD OBSERVED AND BOOSTRAP ESTIMATES
// ************************************
use "${foldlog}\simex-data-std.dta", clear

gen data = 0

foreach i of numlist 1(1)200 {

	noi di "Reading bootstrap sample `i'"

	cap append using "${foldlog}\simex-data-std-boot`i'.dta"
	
	replace data =`i' if data == .
}	

// define outcomes

macro def Y F57_1__std THCS_CUM_std GHRI_36_std 

// paste in predictions from regressions of W on Y0

local high_F57_1__std   = 1.048193     
local low_F57_1__std    = -0.5647687

local high_THCS_CUM_std = 1.042546
local low_THCS_CUM_std  = -0.5642121

local high_GHRI_36_std = 1.045546
local low_GHRI_36_std  = -0.5632206

// ****************************************
// ESTIMATE THE LOCATION-SHIFT FACTOR MODEL
// ****************************************

foreach v in $Y {

	gen hat2lY0_`v' = .       // estimate of quantile loadings under location-shift
	gen hat2lY1_`v' = .

	gen hat1QDG_high_`v' = .  // estimate of QCD
	gen hat1QDG_low_`v' = .
	gen hat2QDG_high_`v' = .  // estimate of QCD under location-shift
	gen hat2QDG_low_`v' = .

	gen lambda1_`v' = .  // estimate of lambda of the location-shift model
	gen lambda0_`v' = .
	gen gamma1_`v' = .  // estimate of gamma of the location-shift model
	gen gamma0_`v' = .
	
	foreach i of numlist 0(1)200 {
	
		noi di "Computation for outcome `v' from bootstrap sample `i'"

		quietly {
		
		// regress SIMEX loading on SIMEX uniqueness
		// control group

		qui reg lY0_`v' qY0_`v' if data == `i'
		
		replace lambda0_`v' = _b[_cons] if data == `i'
		replace gamma0_`v' = _b[qY0_`v'] if data == `i'
		
		qui sum qY0_`v' if data == `i' & tau == 50 // this is used for QCD below
		local u = r(mean)
		local l0 = _b[_cons] + _b[qY0_`v']*`u'
		
		// treatment group
		
		qui reg lY1_`v' qY1_`v' if data == `i'

		replace lambda1_`v' = _b[_cons] if data == `i'
		replace gamma1_`v' = _b[qY1_`v'] if data == `i'

		// predict location-shift loadings under location-shift
		
		replace hat2lY0_`v' = lambda0_`v' + gamma0_`v'*qY0_`v' if data == `i'
		replace hat2lY1_`v' = lambda1_`v' + gamma1_`v'*qY1_`v' if data == `i'
		
		// predict QDG under location-shift

		replace hat2QDG_high_`v' = (hat2lY1_`v' - `l0')*`high_`v''  + qY1_`v' - `u' if data == `i'
		replace hat2QDG_low_`v'  = (hat2lY1_`v' - `l0')*`low_`v'' + qY1_`v' - `u' if data == `i'
		
		// predict QDG under general model
		
		qui sum lY0_`v' if data == `i' & tau == 50
		
		replace hat1QDG_high_`v' = (lY1_`v' - r(mean))*`high_`v''  + qY1_`v' - `u' if data == `i'
		replace hat1QDG_low_`v'  = (lY1_`v' - r(mean))*`low_`v'' + qY1_`v' - `u' if data == `i'
		
		} // ends quietly
	} // ends boostrap sample
	
	label var qY0_`v' "C: intercepts under general model"
	label var qY1_`v' "T: intercepts under general model"
	label var lY0_`v' "C: slopes under general model"
	label var lY1_`v' "T: slopes under general model"
	label var hat2lY0_`v' "C: slopes under location-shift model"
	label var hat2lY1_`v' "T: slopes under location-shift model"
	label var hat1QDG_high_`v' "QCD under general model"
	label var hat1QDG_low_`v' "QCD under general model"
	label var hat2QDG_high_`v' "QCD under location-shift model"
	label var hat2QDG_low_`v' "QCD under location-shift model"
	
} // ends outcome

// ********************
// CONFIDENCE INTERVALS
// ********************

foreach v in $Y {

	noi di "Computation for outcome `v' from bootstrap sample `i'"

	quietly {
	
	// slopes under the location-shift model

	bysort tau: egen sup_hat2lY0_`v' = pctile(cond(data != 0, hat2lY0_`v', .)), p(95)
	bysort tau: egen inf_hat2lY0_`v' = pctile(cond(data != 0, hat2lY0_`v', .)), p(5)
	label var sup_hat2lY0_`v' "C: 95pct slopes under location-shift model"
	label var inf_hat2lY0_`v' "C: 5pct slopes under location-shift model"
	 
	bysort tau: egen sup_hat2lY1_`v' = pctile(cond(data != 0, hat2lY1_`v', .)), p(95)
	bysort tau: egen inf_hat2lY1_`v' = pctile(cond(data != 0, hat2lY1_`v', .)), p(5)
	label var sup_hat2lY1_`v' "T: 95pct slopes under location-shift model"
	label var inf_hat2lY1_`v' "T: 5pct slopes under location-shift model"
	
	// slopes under the general model

	bysort tau: egen sup_lY0_`v' = pctile(cond(data != 0, lY0_`v', .)), p(95)
	bysort tau: egen inf_lY0_`v' = pctile(cond(data != 0, lY0_`v', .)), p(5)
	label var sup_lY0_`v' "C: 95pct slopes under general model"
	label var inf_lY0_`v' "C: 5pct slopes under general model"
	 
	bysort tau: egen sup_lY1_`v' = pctile(cond(data != 0, lY1_`v', .)), p(95)
	bysort tau: egen inf_lY1_`v' = pctile(cond(data != 0, lY1_`v', .)), p(5)
	label var sup_lY1_`v' "T: 95pct slopes under general model"
	label var inf_lY1_`v' "T: 5pct slopes under general model"

	// intercepts
	
	bysort tau: egen sup_qY0_`v' = pctile(cond(data != 0, qY0_`v', .)), p(95)
	bysort tau: egen inf_qY0_`v' = pctile(cond(data != 0, qY0_`v', .)), p(5)
	label var sup_qY0_`v' "C: 95pct intercepts under general model"
	label var inf_qY0_`v' "C: 5pct intercepts under general model"
	
	bysort tau: egen sup_qY1_`v' = pctile(cond(data != 0, qY1_`v', .)), p(95)
	bysort tau: egen inf_qY1_`v' = pctile(cond(data != 0, qY1_`v', .)), p(5)
	label var sup_qY1_`v' "T: 95pct intercepts under general model"
	label var inf_qY1_`v' "T: 5pct intercepts under general model"

	// QCD under the location-shift model
	
	bysort tau: egen sup_hat2QDG_high_`v' = pctile(cond(data != 0, hat2QDG_high_`v', .)), p(95)
	bysort tau: egen sup_hat2QDG_low_`v'  = pctile(cond(data != 0, hat2QDG_low_`v', .)), p(95)
	label var sup_hat2QDG_high_`v' "95pct QCD under location-shift model"
	label var sup_hat2QDG_low_`v'  "95pct QCD under location-shift model"

	bysort tau: egen inf_hat2QDG_high_`v' = pctile(cond(data != 0, hat2QDG_high_`v', .)), p(5)
	bysort tau: egen inf_hat2QDG_low_`v'  = pctile(cond(data != 0, hat2QDG_low_`v', .)), p(5)
	label var inf_hat2QDG_high_`v' "5pct QCD under location-shift model"
	label var inf_hat2QDG_low_`v'  "5pct QCD under location-shift model"
	
	// QCD under the general model

	bysort tau: egen sup_hat1QDG_high_`v' = pctile(cond(data != 0, hat1QDG_high_`v', .)), p(95)
	bysort tau: egen sup_hat1QDG_low_`v'  = pctile(cond(data != 0, hat1QDG_low_`v', .)), p(95)
	label var sup_hat1QDG_high_`v' "95pct QCD under general model"
	label var sup_hat1QDG_low_`v'  "95pct QCD under general model"

	bysort tau: egen inf_hat1QDG_high_`v' = pctile(cond(data != 0, hat1QDG_high_`v', .)), p(5)
	bysort tau: egen inf_hat1QDG_low_`v'  = pctile(cond(data != 0, hat1QDG_low_`v', .)), p(5)	
	label var inf_hat1QDG_high_`v' "5pct QCD under general model"
	label var inf_hat1QDG_low_`v'  "5pct QCD under general model"
	
	} // ends quietly
} // ends outcome

// ******************************
// EXPORT RESULTS FOR GRAPHS IN R
// ******************************

preserve

keep if data == 0
sort tau

macro def SAVE

foreach v in $Y {

	#delimit ;
	macro def SAVE $SAVE 
	lY0_`v' sup_lY0_`v' inf_lY0_`v' lY1_`v' sup_lY1_`v' inf_lY1_`v'
	qY0_`v' sup_qY0_`v' inf_qY0_`v' qY1_`v' sup_qY1_`v' inf_qY1_`v'
	hat2lY0_`v' sup_hat2lY0_`v' inf_hat2lY0_`v' hat2lY1_`v' sup_hat2lY1_`v' inf_hat2lY1_`v'
	hat1QDG_high_`v' sup_hat1QDG_high_`v' inf_hat1QDG_high_`v' hat1QDG_low_`v' sup_hat1QDG_low_`v' inf_hat1QDG_low_`v'
	hat2QDG_high_`v' sup_hat2QDG_high_`v' inf_hat2QDG_high_`v' hat2QDG_low_`v' sup_hat2QDG_low_`v' inf_hat2QDG_low_`v';
	#delimit cr
}

export excel tau $SAVE if data == 0 using "${foldlog}\dataRgraphs.xlsx", firstrow(variables) replace

macro def SAVE

foreach v in F57_1__std {

	#delimit ;
	macro def SAVE $SAVE 
	lY0_`v' sup_lY0_`v' inf_lY0_`v' lY1_`v' sup_lY1_`v' inf_lY1_`v'
	qY0_`v' sup_qY0_`v' inf_qY0_`v' qY1_`v' sup_qY1_`v' inf_qY1_`v'
	hat2lY0_`v' sup_hat2lY0_`v' inf_hat2lY0_`v' hat2lY1_`v' sup_hat2lY1_`v' inf_hat2lY1_`v'
	hat1QDG_high_`v' sup_hat1QDG_high_`v' inf_hat1QDG_high_`v' hat1QDG_low_`v' sup_hat1QDG_low_`v' inf_hat1QDG_low_`v'
	hat2QDG_high_`v' sup_hat2QDG_high_`v' inf_hat2QDG_high_`v' hat2QDG_low_`v' sup_hat2QDG_low_`v' inf_hat2QDG_low_`v';
	#delimit cr
}

describe $SAVE, fullnames

restore

// ****************************************************
// TESTS FOR LOADINGS AND HETEROSKEDASTICITY PARAMETERS
// ****************************************************

bysort data: gen n = _n

local filewrite="replace"	

foreach v in $Y {

	// loadings from SIMEX are loadings from FACTOR?

	qui reg lambda1_`v' if n == 1 & data != 0
	outreg2 using "${foldlog}\simex-loadings.xls", `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Sample, T)
	local filewrite="append"
	
	qui reg lambda0_`v' if n == 1 & data != 0
	outreg2 using "${foldlog}\simex-loadings.xls", `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Sample, C)
	
	qui gen tmpdiff = lambda1_`v' - lambda0_`v'
	qui reg tmpdiff if n == 1 & data != 0
	outreg2 using "${foldlog}\simex-loadings.xls", `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Sample, T-C)
	drop tmpdiff
	
	// heteroskedasticity is the same between T and C?
	
	qui reg gamma1_`v' if n == 1 & data != 0
	outreg2 using "${foldlog}\simex-loadings.xls", `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Sample, T)

	qui reg gamma0_`v' if n == 1 & data != 0
	outreg2 using "${foldlog}\simex-loadings.xls", `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Sample, C)
	
	qui gen tmpdiff = gamma1_`v' - gamma0_`v'
	qui reg tmpdiff if n == 1 & data != 0
	outreg2 using "${foldlog}\simex-loadings.xls", `filewrite' $tab $ast $stat $nolabel sdec($nsdec) bdec($nbdec) addtext(Sample, T-C)
	drop tmpdiff
}

// ******
// GRAPHS
// ******

// loadings	

preserve

keep if data == 0
sort tau

local   title_F57_1__std = "Cognitive Development Index"
local title_THCS_CUM_std = "Morbidity Index"
local  title_GHRI_36_std = "General Health Ratings Index"

foreach v in $Y {

	#delimit ;
	twoway (scatter lY0_`v' tau, mcolor(black) msize(tiny))
	       (scatter lY1_`v' tau, mcolor(red) msize(tiny))
	       (rarea sup_hat2lY0_`v' inf_hat2lY0_`v' tau, fcolor(black%5) lcolor(black%5) lwidth(none))
           (rarea sup_hat2lY1_`v' inf_hat2lY1_`v' tau, fcolor(red%5) lcolor(red%5) lwidth(none))
	       (line hat2lY0_`v' tau, lpattern(solid) lcolor(black))
		   (line hat2lY1_`v' tau, lpattern(dash) lcolor(red))
		   if inrange(tau,6,94),
		   legend(order(3 "control" 4 "treated") size(vsmall))
		   ytitle("") /*yscale(range(-0.3 0.6)) ylabel(-0.2(0.2)0.6, labsize(tiny)) */
	       xtitle(quantile) xscale(range(1 99)) xlabel(5(5)95, labsize(tiny))
		   subtitle("`title_`v''")
		   scheme(white_w3d)
		   saving("${foldlog}\gr_`v'.gph", replace);
	#delimit cr
}

qui graph combine "${foldlog}\gr_F57_1__std.gph" "${foldlog}\gr_THCS_CUM_std.gph" "${foldlog}\gr_GHRI_36_std.gph", row(1) scheme(white_w3d)

erase "${foldlog}\gr_F57_1__std.gph" 
erase "${foldlog}\gr_THCS_CUM_std.gph" 
erase "${foldlog}\gr_GHRI_36_std.gph"

restore

// intercepts

preserve

keep if data == 0
sort tau

local   title_F57_1__std = "Cognitive Development Index"
local title_THCS_CUM_std = "Morbidity Index"
local  title_GHRI_36_std = "General Health Ratings Index"
	
foreach v in $Y {

	#delimit ;
	twoway (rarea sup_qY0_`v' inf_qY0_`v' tau, fcolor(black%5) lcolor(black%5) lwidth(none))
           (rarea sup_qY1_`v' inf_qY1_`v' tau, fcolor(red%5) lcolor(red%5) lwidth(none))
	       (line qY0_`v' tau, lpattern(solid) lcolor(black))
		   (line qY1_`v' tau, lpattern(dash) lcolor(red))
		   if inrange(tau,6,94),
		   legend(order(1 "control" 2 "treated") size(vsmall))
		   ytitle("") /*yscale(range(-0.3 0.6)) ylabel(-0.2(0.2)0.6, labsize(tiny)) */
	       xtitle(quantile) xscale(range(1 99)) xlabel(5(5)95, labsize(tiny))
		   subtitle("`title_`v''")
		   scheme(white_w3d)
		   saving("${foldlog}\gr_`v'.gph", replace);
	#delimit cr
}

qui graph combine "${foldlog}\gr_F57_1__std.gph" "${foldlog}\gr_THCS_CUM_std.gph" "${foldlog}\gr_GHRI_36_std.gph", row(1) scheme(white_w3d)

erase "${foldlog}\gr_F57_1__std.gph" 
erase "${foldlog}\gr_THCS_CUM_std.gph" 
erase "${foldlog}\gr_GHRI_36_std.gph"

restore

// QCD comparison

preserve

keep if data == 0
sort tau

local   title_F57_1__std = "Cognitive Development Index"
local title_THCS_CUM_std = "Morbidity Index"
local  title_GHRI_36_std = "General Health Ratings Index"
	
foreach v in $Y {

	#delimit ;
	twoway (line hat1QDG_high_`v' hat2QDG_high_`v' tau, lpattern(dash solid) lcolor(black red))
	       /*(line hat1QDG_low_`v' hat2QDG_low_`v' tau, lpattern(dash solid) lcolor(black red))*/
		   if inrange(tau,6,94),	   
		   legend(order(1 "HLBW-G" 2 "HLBW-LS" 3 "LLBW-G" 4 "LLBW-LS") size(vsmall))
		   ytitle("") yscale(range(-2.2 2)) ylabel(-2(0.2)1.8, labsize(tiny))
	       xtitle(quantile) xscale(range(5 95)) xlabel(10(5)90, labsize(tiny))
		   subtitle("`title_`v''")
		   scheme(white_w3d)
		   saving("${foldlog}\qcd_`v'.gph", replace);
	#delimit cr
}

qui graph combine "${foldlog}\qcd_F57_1__std.gph" "${foldlog}\qcd_THCS_CUM_std.gph" "${foldlog}\qcd_GHRI_36_std.gph", row(1) scheme(white_w3d)

erase "${foldlog}\qcd_F57_1__std.gph" 
erase "${foldlog}\qcd_THCS_CUM_std.gph" 
erase "${foldlog}\qcd_GHRI_36_std.gph"

restore

// QDG general model	

preserve

keep if data == 0
sort tau

local   title_F57_1__std = "Cognitive Development Index"
local title_THCS_CUM_std = "Morbidity Index"
local  title_GHRI_36_std = "General Health Ratings Index"

* average effects from the table

local   avghigh_F57_1__std = 0.2616343
local avghigh_THCS_CUM_std = -0.07673
local  avghigh_GHRI_36_std = 0.0901077

local   avglow_F57_1__std = -0.1482296
local avglow_THCS_CUM_std = 0.0444145
local  avglow_GHRI_36_std = 0.025

* this is to place labels

local   lochigh_F57_1__std = 0.2616343*1.07
local lochigh_THCS_CUM_std = -0.07673*0.85
local  lochigh_GHRI_36_std = 0.0901077*1.23

local   loclow_F57_1__std = -.1482296*0.90
local loclow_THCS_CUM_std = 0.0444145*1.13
local  loclow_GHRI_36_std = -0.0516686*1.50

foreach v in $Y {

	#delimit ;
	twoway (rarea sup_hat1QDG_high_`v' inf_hat1QDG_high_`v' tau, fcolor(black%5) lcolor(black%5) lwidth(none))
	       (rarea sup_hat1QDG_low_`v' inf_hat1QDG_low_`v' tau, fcolor(red%5) lcolor(red%5) lwidth(none))
	       (line hat1QDG_high_`v' hat1QDG_low_`v' tau, lpattern(dash solid) lcolor(black red))
		   if inrange(tau,6,94),
		   yline(`avghigh_`v'' `avglow_`v'', lcolor(green))
		   text(`lochigh_`v'' 10 "HLBW", place(n) size(tiny) color(black))		   
		   text(`loclow_`v''  10 "LLBW", place(n) size(tiny) color(black))		   
		   legend(order(1 "HLBW" 2 "LLBW") size(vsmall))
		   ytitle("") yscale(range(-2.2 2)) ylabel(-2(0.2)1.8, labsize(tiny))
	       xtitle(quantile) xscale(range(5 95)) xlabel(10(5)90, labsize(tiny))
		   subtitle("`title_`v''")
		   scheme(white_w3d)
		   saving("${foldlog}\qcd_`v'.gph", replace);
	#delimit cr
}	

qui graph combine "${foldlog}\qcd_F57_1__std.gph" "${foldlog}\qcd_THCS_CUM_std.gph" "${foldlog}\qcd_GHRI_36_std.gph", row(1) scheme(white_w3d)

erase "${foldlog}\qcd_F57_1__std.gph" 
erase "${foldlog}\qcd_THCS_CUM_std.gph" 
erase "${foldlog}\qcd_GHRI_36_std.gph"

restore

